"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const file_1 = __importDefault(require("./helper/file"));
const xml_1 = __importDefault(require("./helper/xml"));
class Chart {
    constructor(relsXmlInfo, sourceArchive, targetSlideNumber) {
        this.sourceNumber = relsXmlInfo.number;
        this.sourceRid = relsXmlInfo.rId;
        this.sourceArchive = sourceArchive;
        this.targetSlideNumber = targetSlideNumber;
    }
    setTarget(archive, number) {
        this.targetArchive = archive;
        this.targetNumber = number;
        // this.targetNumber = this.sourceNumber
    }
    append() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.copyFiles();
            yield this.appendTypes();
        });
    }
    copyFiles() {
        return __awaiter(this, void 0, void 0, function* () {
            this.copyChartFiles();
            let wbRelsPath = `ppt/charts/_rels/chart${this.sourceNumber}.xml.rels`;
            let worksheets = yield xml_1.default.getTargetsFromRelationships(this.sourceArchive, wbRelsPath, '../embeddings/Microsoft_Excel_Worksheet', '.xlsx');
            let worksheet = worksheets[0];
            this.sourceWorksheet = (worksheet.number === 0) ? '' : worksheet.number;
            this.targetWorksheet = this.targetNumber;
            this.copyWorksheetFile();
            this.editTargetWorksheetRel();
            this.editTargetChartRel();
        });
    }
    appendTypes() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.appendChartExtensionToContentType();
            yield this.appendChartToContentType();
            yield this.appendColorToContentType();
            yield this.appendStyleToContentType();
        });
    }
    copyChartFiles() {
        return __awaiter(this, void 0, void 0, function* () {
            file_1.default.zipCopy(this.sourceArchive, `ppt/charts/chart${this.sourceNumber}.xml`, this.targetArchive, `ppt/charts/chart${this.targetNumber}.xml`);
            file_1.default.zipCopy(this.sourceArchive, `ppt/charts/colors${this.sourceNumber}.xml`, this.targetArchive, `ppt/charts/colors${this.targetNumber}.xml`);
            file_1.default.zipCopy(this.sourceArchive, `ppt/charts/style${this.sourceNumber}.xml`, this.targetArchive, `ppt/charts/style${this.targetNumber}.xml`);
            file_1.default.zipCopy(this.sourceArchive, `ppt/charts/_rels/chart${this.sourceNumber}.xml.rels`, this.targetArchive, `ppt/charts/_rels/chart${this.targetNumber}.xml.rels`);
        });
    }
    editTargetChartRel() {
        return __awaiter(this, void 0, void 0, function* () {
            let targetRelFile = `ppt/slides/_rels/slide${this.targetSlideNumber}.xml.rels`;
            let relXml = yield xml_1.default.getXmlFromArchive(this.targetArchive, targetRelFile);
            let relations = relXml.getElementsByTagName('Relationship');
            for (let i in relations) {
                let element = relations[i];
                if (element.getAttribute) {
                    let rId = element.getAttribute('Id');
                    if (rId === this.sourceRid) {
                        element.setAttribute('Target', `../charts/chart${this.targetNumber}.xml`);
                    }
                }
            }
            xml_1.default.writeXmlToArchive(this.targetArchive, targetRelFile, relXml);
        });
    }
    editTargetWorksheetRel() {
        return __awaiter(this, void 0, void 0, function* () {
            let targetRelFile = `ppt/charts/_rels/chart${this.targetNumber}.xml.rels`;
            let relXml = yield xml_1.default.getXmlFromArchive(this.targetArchive, targetRelFile);
            let relations = relXml.getElementsByTagName('Relationship');
            for (let i in relations) {
                let element = relations[i];
                if (element.getAttribute) {
                    let type = element.getAttribute('Type');
                    switch (type) {
                        case "http://schemas.openxmlformats.org/officeDocument/2006/relationships/package":
                            element.setAttribute('Target', `../embeddings/Microsoft_Excel_Worksheet${this.targetWorksheet}.xlsx`);
                            break;
                        case "http://schemas.microsoft.com/office/2011/relationships/chartColorStyle":
                            element.setAttribute('Target', `colors${this.targetNumber}.xml`);
                            break;
                        case "http://schemas.microsoft.com/office/2011/relationships/chartStyle":
                            element.setAttribute('Target', `style${this.targetNumber}.xml`);
                            break;
                    }
                }
            }
            xml_1.default.writeXmlToArchive(this.targetArchive, targetRelFile, relXml);
        });
    }
    copyWorksheetFile() {
        return __awaiter(this, void 0, void 0, function* () {
            file_1.default.zipCopy(this.sourceArchive, `ppt/embeddings/Microsoft_Excel_Worksheet${this.sourceWorksheet}.xlsx`, this.targetArchive, `ppt/embeddings/Microsoft_Excel_Worksheet${this.targetWorksheet}.xlsx`);
        });
    }
    appendChartExtensionToContentType() {
        return xml_1.default.appendIf(Object.assign(Object.assign({}, xml_1.default.createContentTypeChild(this.targetArchive, {
            Extension: `xlsx`,
            ContentType: `application/vnd.openxmlformats-officedocument.spreadsheetml.sheet`
        })), { tag: 'Default', clause: (xml) => !xml_1.default.findByAttribute(xml, 'Default', 'Extension', 'xlsx') }));
    }
    appendChartToContentType() {
        return xml_1.default.append(xml_1.default.createContentTypeChild(this.targetArchive, {
            PartName: `/ppt/charts/chart${this.targetNumber}.xml`,
            ContentType: `application/vnd.openxmlformats-officedocument.drawingml.chart+xml`
        }));
    }
    appendColorToContentType() {
        return xml_1.default.append(xml_1.default.createContentTypeChild(this.targetArchive, {
            PartName: `/ppt/charts/colors${this.targetNumber}.xml`,
            ContentType: `application/vnd.ms-office.chartcolorstyle+xml`
        }));
    }
    appendStyleToContentType() {
        return xml_1.default.append(xml_1.default.createContentTypeChild(this.targetArchive, {
            PartName: `/ppt/charts/style${this.targetNumber}.xml`,
            ContentType: `application/vnd.ms-office.chartstyle+xml`
        }));
    }
}
exports.default = Chart;
//# sourceMappingURL=chart.js.map